/**
 * Developed by StickyPages.ca
 * For Assistant7/Report7.co
 */
const tenant = assistant7vars.tenantId
const apiUrl = 'https://api.commerce7.com/v1'
var countReviews = 0
var reviewsSummed = 0

if(tenant.length < 1) {
	console.log('A7, Please enter your tenant in the admin')
}

(function( $ ) {
	'use strict';

	// Lets find the product slug from the URL
	const pathArray = window.location.pathname.split('/').filter(Boolean)
	const page = pathArray[0]
	const productSlug = pathArray[pathArray.length-1]

	// Submit review
	$(document).on('click', '#assistant7-submit-review', function(e) {
		let rev = {
			"tenant": tenant,
			"uuid": $('#assistant7-add-review #uuid').val(),
			"name": $('#assistant7-add-review #name').val(),
			"email": $('#assistant7-add-review #email').val(),
			"rating": $('input.ass7star:checked').val(),
			"comments": $('#assistant7-add-review #comments').val(),
			"productName": $('#assistant7-add-review #productName').val()
		}

		$.ajax({
			type: "POST",
			url: `https://api.report7.co/review`,
			data: JSON.stringify(rev),
		}).done(res => {
			if(res.code === 200 && res.results.payload) {
				$('#no-reviews').hide()
				$('#assistant7-reviews').prepend(assistant7_template_review(JSON.parse(res.results.payload)))
				$('#assistant7-add-review #name').val('')
				$('#assistant7-add-review #email').val('')
				$('#assistant7-add-review #comments').val('')
			}
		});
		e.preventDefault();
	})

	// Retrieve the product from Commerce7
	if(productSlug && ("product" === page) ) {
		$.ajax({
			url: `${apiUrl}/product-for-web/${productSlug}`,
			headers: {tenant}
		}).done(product => {
			if (product) {

				// Load reviews
				waitForElementToDisplay("#assistant7-reviews",function(){
					let reviews = $('#assistant7-reviews')
					if (reviews.length) {
						$.ajax({
							url: `https://api.report7.co/review/${product.id}`,
							data: {tenant}
						}).done(res => {
							if (res && (res._total > 0)) {
								for (let revKey in res.results) {
									countReviews += 1
									reviews.append(assistant7_template_review(res.results[revKey]))
								}
							} else {
								reviews.append('<div id="no-reviews">Be the first to review!</div>')
							}
						})
					}
				},1000,9000)

				// Load reviews form
				waitForElementToDisplay("#assistant7-reviews-form",function(){
					let reviewsForm = $('#assistant7-reviews-form')
					if (reviewsForm.length) {
						reviewsForm.append(assistant7_submit_review(product.id))
					}
				},1000,9000)

				// Set product name in the form
				waitForElementToDisplay(".c7-product-detail__titles",function(){
					let productName = $('h1.c7-product-detail__titles').text()
					$('#assistant7-add-review #productName').val(productName)
				}, 1000, 9000)
			}
		});
	}
})( jQuery );

function waitForElementToDisplay(selector, callback, checkFrequencyInMs, timeoutInMs) {
	var startTimeInMs = Date.now();
	(function loopSearch() {
		if (document.querySelector(selector) != null) {
			callback();
			return;
		}
		else {
			setTimeout(function () {
				if (timeoutInMs && Date.now() - startTimeInMs > timeoutInMs)
					return;
				loopSearch();
			}, checkFrequencyInMs);
		}
	})();
}

/* DISPLAY "FROM NOW TIME */
var timeFromNow = function (time) {
	if(typeof time === 'string') {
		time = parseInt(time)
	}
	// Get timestamps
	var unixTime = new Date(time).getTime();
	if (!unixTime) return;
	var now = new Date().getTime();

	// Calculate difference (depends on what's being inputed)
	// var difference = (unixTime / 1000) - (now / 1000);
	var difference = (unixTime) - (now / 1000);

	var tfn = {};

	// Check if time is in the past, present, or future
	tfn.when = 'now';
	if (difference > 0) {
		tfn.when = 'future';
	} else if (difference < -1) {
		tfn.when = 'past';
	}

	// Convert difference to absolute
	difference = Math.abs(difference);

	// Calculate time unit
	if (difference / (60 * 60 * 24 * 365) > 1) {
		// Years
		tfn.unitOfTime = 'years';
		tfn.time = Math.floor(difference / (60 * 60 * 24 * 365));
	} else if (difference / (60 * 60 * 24 * 45) > 1) {
		// Months
		tfn.unitOfTime = 'months';
		tfn.time = Math.floor(difference / (60 * 60 * 24 * 45));
	} else if (difference / (60 * 60 * 24) > 1) {
		// Days
		tfn.unitOfTime = 'days';
		tfn.time = Math.floor(difference / (60 * 60 * 24));
	} else if (difference / (60 * 60) > 1) {
		// Hours
		tfn.unitOfTime = 'hours';
		tfn.time = Math.floor(difference / (60 * 60));
	} else if (difference / (60) > 1) {
		// Minutes
		tfn.unitOfTime = 'minutes';
		tfn.time = Math.floor(difference / (60));
	} else {
		// Seconds
		tfn.unitOfTime = 'seconds';
		tfn.time = Math.floor(difference);
	}
	return tfn;
};

/* TEMPLATE FOR EACH REVIEW */
function assistant7_template_review(e) {
	let ratings = ''
	let ago = ''
	let ratingsCount = 0

	if(e.rating && e.rating < 6) {
		for (i = 0; i <= (e.rating-1); i++) {
			ratings += `<span></span>`
			ratingsCount += 1
		}
		reviewsSummed += ratingsCount
	}
	if(e.docCreatedAt.length > 1) {
		let tAgo = timeFromNow(e.docCreatedAt)
		ago += `<span class="assistant7-ago">`
		if(tAgo.when === 'past') {
			ago += `${tAgo.time} ${tAgo.unitOfTime} ago`
		}
		ago += `</span>`
	}

	return `<div class="assistant7-review" itemType="http://schema.org/Product" itemScope>
		<meta itemProp="name" content="${e.productName}"/>

		<div itemProp="review" itemType="http://schema.org/Review" itemScope>
			<div itemProp="author" itemType="http://schema.org/Person" itemScope>
				<meta itemProp="name" content="${e.name}"/>
				<span class="assistant7-name">${e.name}</span> <span class="assistant7-ago">${ago}</span>
			</div>
			<div itemProp="reviewRating" itemType="http://schema.org/Rating" itemScope>
				<span class='assistant7-rating-display'>${ratings}</span>
				<meta itemProp="ratingValue" content="${ratingsCount}"/>
				<meta itemProp="bestRating" content="5"/>
			</div>
			<div class='assistant7-comment'>${e.comments}</div>
		</div>
	</div>`
}

/* REVIEW FORM */
function assistant7_submit_review(uuid) {
	return `<a href="#add-review"></a><form id="assistant7-add-review">
	<div class="twoCol">
		<label>Name<input id="name" name="name" type="text" placeholder="Name" required="required"></label>
		<label>Email <small>(optional)</small><input id="email" name="email" type="email" placeholder="Email"></label>
	</div>
	<label>Comment<textarea id="comments" name="comments" required></textarea>
	<div id="assistant7-rating-input">
		<label>Rating</label>
		<div class="assistant7-rating">
			<input class="ass7star star-5" id="star-5-2" type="radio" name="star" value="5" />
			<label class="ass7star star-5" for="star-5-2"></label>
			<input class="ass7star star-4" id="star-4-2" type="radio" name="star" value="4" />
			<label class="ass7star star-4" for="star-4-2"></label>
			<input class="ass7star star-3" id="star-3-2" type="radio" name="star" value="3" />
			<label class="ass7star star-3" for="star-3-2"></label>
			<input class="ass7star star-2" id="star-2-2" type="radio" name="star" value="2" />
			<label class="ass7star star-2" for="star-2-2"></label>
			<input class="ass7star star-1" id="star-1-2" type="radio" name="star" value="1" />
			<label class="ass7star star-1" for="star-1-2"></label>
		</div>
	</div>
	<input type="hidden" name="productName" id="productName" value="">
	<input type="hidden" name="uuid" id="uuid" value="${uuid}">
	<button id="assistant7-submit-review" class="c7-button">Submit</button>
</form>`
}
